pub struct ContainerHealthCheck { /* private fields */ }Expand description
Async health check that probes the Docker daemon via Docker::ping().
Implementations
Sourceimpl ContainerHealthCheck
impl ContainerHealthCheck
Sourcepub fn new(config: &ContainerConfig) -> Self
pub fn new(config: &ContainerConfig) -> Self
Creates a new health check using the given endpoint config. The Docker client is created lazily during the probe.