ContainerConsumer

Struct ContainerConsumer 

pub struct ContainerConsumer { /* private fields */ }
Consumer for receiving Docker container events or logs.

This consumer subscribes to Docker events or container logs and forwards them to the route as exchanges. It implements automatic reconnection on connection failures.

Implementations

Source

impl ContainerConsumer

pub fn new( config: ContainerConfig, runtime: Arc<dyn RuntimeObservability>, ) -> Self