pub struct ContainerComponent { /* private fields */ }Expand description
Component for creating container endpoints.
This component handles URIs with the “container” scheme and creates appropriate producer and consumer endpoints for Docker operations.
Containers created via run operation are tracked globally and can be
cleaned up on shutdown by calling cleanup_tracked_containers().
Implementations
Sourceimpl ContainerComponent
impl ContainerComponent
Sourcepub fn with_config(config: ContainerGlobalConfig) -> Self
pub fn with_config(config: ContainerGlobalConfig) -> Self
Creates a container component with the given global config.
Sourcepub fn with_optional_config(config: Option<ContainerGlobalConfig>) -> Self
pub fn with_optional_config(config: Option<ContainerGlobalConfig>) -> Self
Creates a container component with optional global config.