pub struct ContainerConsumer { /* private fields */ }Expand description
Consumer for receiving Docker container events or logs.
This consumer subscribes to Docker events or container logs and forwards them to the route as exchanges. It implements automatic reconnection on connection failures.